@@ -350,8 +350,8 @@
 #'
 #' @note
 #' This function is based on the \code{multilevelR2()} function from the \pkg{mitml}
-#' package by Simon Grund, Alexander Robitzsch and Oliver Luedtke (2021) and
-#' calls the \code{r2mlm()} function in the \pkg{r2mlm} package by Mairead Shaw,
+#' package by Simon Grund, Alexander Robitzsch and Oliver Luedtke (2021), and a
+#' copy of the function \code{r2mlm} in the \pkg{r2mlm} package by Mairead Shaw,
 #' Jason Rights, Sonya Sterba, and Jessica Flake.
 #'
 #' @export
@@ -445,6 +445,9 @@
 #'         legend.box.margin = margin(-10, 6, 6, 6)) +
 #'   guides(fill = guide_legend(nrow = 2, reverse = TRUE))
 #' }
+
+
+
 multilevel.r2 <- function(model, print = c("all", "RB", "SB", "NS", "RS"), digits = 3,
                           plot = FALSE, gray = FALSE, start = 0.15, end = 0.85,
                           color = c("#D55E00", "#0072B2", "#CC79A7", "#009E73", "#E69F00"),
@@ -507,6 +510,12 @@ multilevel.r2 <- function(model, print = c("all", "RB", "SB", "NS", "RS"), digit
 
   }
 
+  #_____________________________________________________________________________
+  #
+  # Internal Functions ---------------------------------------------------------
+
+
+
   #_____________________________________________________________________________
   #
   # Arguments ------------------------------------------------------------------
@@ -711,18 +720,646 @@ multilevel.r2 <- function(model, print = c("all", "RB", "SB", "NS", "RS"), digit
 
   if (isTRUE("RS" %in% print)) {
 
-    # r2mlm package
-    if (isTRUE("RS" %in% print & !nzchar(system.file(package = "r2mlm")))) { stop("Package \"r2mlm\" is needed for to compute R-squared according to Rights and Sterba (2019), please install the package.", call. = FALSE) }
+    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    ## Internal functions from the r2mlm package ####
 
-    r2mlm.out <- r2mlm::r2mlm(model, bargraph = FALSE)
+    #### r2mlm() Function ####
+    r2mlm <- function(model) {
+
+      temp_formula <- formula(model)
+      grepl_array <- grepl("I(", temp_formula, fixed = TRUE)
+
+      for (bool in grepl_array) {
+        if (isTRUE(bool)) {
+
+          stop("Error: r2mlm does not allow for models fit using the I() function; user must thus manually include any desired transformed predictor variables such as x^2 or x^3 as separate columns in dataset.")
+
+        }
+
+      }
+
+      # call appropriate r2mlm helper function
+      if (isTRUE(typeof(model) == "list")) {
+
+        r2mlm_nlme(model)
+
+      } else if (isTRUE(typeof(model) == "S4")) {
+
+        r2mlm_lmer(model)
+
+      } else {
+
+        stop("You must input a model generated using either the lme4 or nlme package.")
+
+      }
+
+    }
+
+    #### r2mlm_lmer() Function ####
+    r2mlm_lmer <- function(model) {
+
+      # Visible global function defnition
+      is <- fixef <- getME <- NULL
+
+      # Step 1) check if model has_intercept
+      if (isTRUE(attr(terms(model), which = "intercept") == 1L)) {
+
+        has_intercept <- TRUE
+
+      } else {
+
+        has_intercept <- FALSE
+
+      }
+
+      # Step 2) Pull all variable names from the formula
+      all_variables <- all.vars(formula(model))
+      cluster_variable <- all_variables[length(all_variables)]
+
+      # Step 3a) Pull and prepare data
+      data <- prepare_data(model, "lme4", cluster_variable)
+
+      # Step 3b) Determine whether data is appropriate format
+      # a) Pull all variables except for cluster
+      outcome_and_predictors <- all_variables[1L:(length(all_variables) - 1L)]
+
+      # b) If any of those variables is non-numeric, then throw an error
+      for (variable in outcome_and_predictors) {
+
+        if (isTRUE(!is(data[[variable]], "integer") && !is(data[[variable]], "numeric"))) {
+
+          stop("Your data must be numeric. Only the cluster variable can be a factor.")
+
+        }
+
+      }
+
+      # Step 4a) Define variables you'll be sorting
+      if (isTRUE(length(outcome_and_predictors) == 1L)) {
+
+        predictors <- get_interaction_vars(model)
+
+      } else {
+
+        predictors <- append(outcome_and_predictors[2L:length(outcome_and_predictors)], get_interaction_vars(model))
+
+      }
+
+      # Step 4b) Create and fill vectors
+      l1_vars <- sort_variables(data, predictors, cluster_variable)$l1_vars
+      l2_vars <- sort_variables(data, predictors, cluster_variable)$l2_vars
+
+      # Step 5) Pull variable names for L1 predictors with random slopes into a variable called random_slope_vars
+      random_slope_vars <- get_random_slope_vars(model, has_intercept, "lme4")
+
+      # Step 6) Determine value of centeredwithincluster
+      if (is.null(l1_vars)) {
+
+        centeredwithincluster <- TRUE
+
+      } else {
+
+        centeredwithincluster <- get_cwc(l1_vars, cluster_variable, data)
+
+      }
+
+      # 7a) within_covs (l1 variables)
+      within <- get_covs(l1_vars, data)
+
+      # 7b) pull column numbers for between_covs (l2 variables)
+      between <- get_covs(l2_vars, data)
+
+      # 7c) pull column numbers for random_covs (l1 variables with random slopes)
+      random <- get_covs(random_slope_vars, data)
+
+      # 8a) gamma_w, fixed slopes for L1 variables (from l1_vars list)
+      gammaw <- c()
+      i <- 1L
+      for (variable in l1_vars) {
+
+        gammaw[i] <- fixef(model)[variable]
+
+        i <- i + 1L
+
+      }
+
+      # 8b) gamma_b, intercept value if hasintercept = TRUE, and fixed slopes for L2 variables (from between list)
+      gammab <- c()
+      if (isTRUE(has_intercept)) {
+
+        gammab[1L] <- fixef(model)[1L]
+
+        i <- 2L
+
+      } else {
+
+        i <- 1L
+
+      }
+
+      for (var in l2_vars) {
+
+        gammab[i] <- fixef(model)[var]
+
+        i = i + 1L
+
+      }
+
+      # Step 9) Tau matrix, results from VarCorr(model)
+      vcov <- VarCorr(model)
+      tau <- as.matrix(Matrix::bdiag(vcov))
+
+      # Step 10) Sigma^2 value, Rij
+      sigma2 <- getME(model, "sigma")^2L
+
+      # Step 11) Input everything into r2mlm_manual
+      r2mlm_manual(as.data.frame(data), within_covs = within, between_covs = between, random_covs = random,
+                   gamma_w = gammaw, gamma_b = gammab, Tau = tau, sigma2 = sigma2, has_intercept = has_intercept, clustermeancentered = centeredwithincluster)
+
+    }
+
+    #### r2mlm_nlme() Function ####
+    r2mlm_nlme <- function(model) {
+
+      # Visible global function defnition
+      is <- getME <- NULL
+
+      # Step 1) check if model has_intercept
+      if (isTRUE(attr(terms(model), which = "intercept") == 1L)) {
+
+        has_intercept = TRUE
+
+      } else {
+
+        has_intercept = FALSE
+
+      }
+
+      # Step 2) Pull all variable names from the formula
+      all_variables <- all.vars(formula(model))
+      cluster_variable <- attr(nlme::getGroups(model), which = "label")
+
+      # Add the grouping var to list of all variables, and calculate formula length (for later use, to iterate)
+      all_variables[length(all_variables) + 1L] <- cluster_variable
+      formula_length <- length(all_variables) # this returns the number of elements in the all_vars list TODO remove this
+
+      # Step 3a) Pull and prepare data
+      data <- prepare_data(model, "nlme", cluster_variable)
+
+      # Step 3b) Determine whether data is appropriate format. Only the cluster variable can be a factor, for now
+
+      outcome_and_predictors <-  all_variables[1L:length(all_variables) - 1L]
+
+      for (variable in outcome_and_predictors) {
+
+        if (isTRUE(!is(data[[variable]], "integer") && !is(data[[variable]], "numeric"))) {
+
+          stop("Your data must be numeric. Only the cluster variable can be a factor.")
+
+        }
+
+      }
+
+      # Step 4a) Define variables you'll be sorting
+      if (isTRUE(length(outcome_and_predictors) == 1L)) {
+
+        predictors <- get_interaction_vars(model)
+
+      } else {
+
+        predictors <- append(outcome_and_predictors[2:length(outcome_and_predictors)], get_interaction_vars(model))
+
+      }
+
+      # Step 4b) Create and fill vectors
+      l1_vars <- sort_variables(data, predictors, cluster_variable)$l1_vars
+      l2_vars <- sort_variables(data, predictors, cluster_variable)$l2_vars
+
+      # Step 5) pull variable names for L1 predictors with random slopes into a variable called random_slope_vars
+      random_slope_vars <- get_random_slope_vars(model, has_intercept, "nlme")
+
+      # Step 6) determine value of centeredwithincluster
+      if (isTRUE(is.null(l1_vars))) {
+
+        centeredwithincluster <- TRUE
+
+      } else {
+
+        centeredwithincluster <- get_cwc(l1_vars, cluster_variable, data)
+
+      }
+
+      # 7a) within_covs (l1 variables)
+      within <- get_covs(l1_vars, data)
+
+      # 7b) Pull column numbers for between_covs (l2 variables)
+      between <- get_covs(l2_vars, data)
+
+      # 7c) Pull column numbers for random_covs (l1 variables with random slopes)
+      random <- get_covs(random_slope_vars, data)
+
+      # 8a) gamma_w, fixed slopes for L1 variables (from l1_vars list)
+      gammaw <- c()
+      i = 1L
+      for (variable in l1_vars) {
+
+        gammaw[i] <- nlme::fixef(model)[variable]
+
+        i = i + 1L
+
+      }
+
+      # 8b) gamma_b, intercept value if hasintercept = TRUE, and fixed slopes for L2 variables (from between list)
+      gammab <- c()
+      if (isTRUE(has_intercept)) {
+
+        gammab[1L] <- nlme::fixef(model)[1L]
+
+        i = 2L
+
+      } else {
+
+        i = 1L
+
+      }
+
+      for (variable in l2_vars) {
+
+        gammab[i] <- nlme::fixef(model)[variable]
+
+        i = i + 1L
+      }
+
+      # Step 9) Tau matrix
+      tau <- nlme::getVarCov(model)
+
+      # Step 10) sigma^2 value, Rij
+      sigma2 <- model$sigma^2
+
+      # Step 11) Input everything into r2mlm_manual
+      r2mlm_manual(as.data.frame(data), within_covs = within, between_covs = between, random_covs = random,
+                   gamma_w = gammaw, gamma_b = gammab, Tau = tau, sigma2 = sigma2, has_intercept = has_intercept, clustermeancentered = centeredwithincluster)
+
+    }
+
+    #### r2mlm_manual() Function ####
+    r2mlm_manual <- function(data, within_covs, between_covs, random_covs,
+                             gamma_w, gamma_b, Tau, sigma2, has_intercept = TRUE, clustermeancentered = TRUE) {
+
+      if (isTRUE(has_intercept)) {
+
+        if (isTRUE(length(gamma_b) > 1L)) gamma <- c(1L, gamma_w, gamma_b[2:length(gamma_b)])
+        if (isTRUE(length(gamma_b) == 1L)) gamma <- c(1L, gamma_w)
+        if (isTRUE(is.null(within_covs))) gamma_w <- 0L
+
+      }
+
+      if (isTRUE(!has_intercept)) {
+
+        gamma <- c(gamma_w, gamma_b)
+        if (isTRUE(is.null(within_covs))) gamma_w <- 0L
+        if (isTRUE(is.null(between_covs))) gamma_b <- 0L
+
+      }
+
+      if (isTRUE(is.null(gamma))) gamma <- 0L
+
+      # Compute phi
+      phi <- var(cbind(1L, data[, c(within_covs)], data[, c(between_covs)]), na.rm = TRUE)
+      if (isTRUE(!has_intercept)) phi <- var(cbind(data[, c(within_covs)], data[, c(between_covs)]), na.rm = TRUE)
+      if (isTRUE(is.null(within_covs) && is.null(within_covs) && !has_intercept)) phi <- 0L
+      phi_w <- var(data[, within_covs], na.rm = TRUE)
+      if (isTRUE(is.null(within_covs))) phi_w <- 0L
+      phi_b <- var(cbind(1L, data[, between_covs]), na.rm = TRUE)
+      if (isTRUE(is.null(between_covs))) phi_b <- 0L
+
+      # Compute psi and kappa
+      var_randomcovs <- var(cbind(1, data[, c(random_covs)]), na.rm = TRUE)
+      if (isTRUE(length(Tau) > 1L)) psi <- matrix(c(diag(Tau)), ncol = 1L)
+      if (isTRUE(length(Tau) == 1L)) psi <- Tau
+      if (isTRUE(length(Tau) > 1L)) kappa <- matrix(c(Tau[lower.tri(Tau) == TRUE]), ncol = 1)
+      if (isTRUE(length(Tau) == 1L)) kappa <- 0L
+
+      v <- matrix(c(diag(var_randomcovs)), ncol = 1L)
+      r <- matrix(c(var_randomcovs[lower.tri(var_randomcovs) == TRUE]), ncol = 1L)
+
+      if (isTRUE(is.null(random_covs))) {
+
+        v <- 0L
+        r <- 0L
+        m <- matrix(1L, ncol = 1L)
+
+      }
+
+      if (isTRUE(length(random_covs) > 0L)) m <- matrix(c(colMeans(cbind(1, data[, c(random_covs)]), na.rm = TRUE)), ncol = 1L)
+
+      # Total variance
+      totalvar_notdecomp <- t(v)%*%psi + 2L*(t(r)%*%kappa) + t(gamma)%*%phi%*%gamma + t(m)%*%Tau%*%m + sigma2
+      totalwithinvar <- (t(gamma_w)%*%phi_w%*%gamma_w) + (t(v)%*%psi + 2L*(t(r)%*%kappa)) + sigma2
+      totalbetweenvar <- (t(gamma_b)%*%phi_b%*%gamma_b) + Tau[1L]
+      totalvar <- totalwithinvar + totalbetweenvar
+
+      # Total decomp
+      decomp_fixed_notdecomp <- (t(gamma)%*%phi%*%gamma) / totalvar_notdecomp
+      decomp_varslopes_notdecomp <- (t(v)%*%psi + 2L*(t(r)%*%kappa)) / totalvar_notdecomp
+      decomp_varmeans_notdecomp <- (t(m)%*%Tau%*%m) / totalvar_notdecomp
+      decomp_sigma_notdecomp <- sigma2/totalvar_notdecomp
+      decomp_fixed_within <- (t(gamma_w)%*%phi_w%*%gamma_w) / totalvar
+      decomp_fixed_between <- (t(gamma_b)%*%phi_b%*%gamma_b) / totalvar
+      decomp_fixed <- decomp_fixed_within + decomp_fixed_between
+      decomp_varslopes <- (t(v)%*%psi + 2L*(t(r)%*%kappa)) / totalvar
+      decomp_varmeans <- (t(m)%*%Tau%*%m) / totalvar
+      decomp_sigma <- sigma2 / totalvar
+
+      # Within decomp
+      decomp_fixed_within_w <- (t(gamma_w)%*%phi_w%*%gamma_w) / totalwithinvar
+      decomp_varslopes_w <- (t(v)%*%psi + 2L*(t(r)%*%kappa)) / totalwithinvar
+      decomp_sigma_w <- sigma2 / totalwithinvar
+
+      # Between decomp
+      decomp_fixed_between_b <- (t(gamma_b)%*%phi_b%*%gamma_b) / totalbetweenvar
+      decomp_varmeans_b <- Tau[1L] / totalbetweenvar
+
+      # New measures
+      if (isTRUE(clustermeancentered)) {
+
+        R2_f <- decomp_fixed
+        R2_f1 <- decomp_fixed_within
+        R2_f2 <- decomp_fixed_between
+        R2_fv <- decomp_fixed + decomp_varslopes
+        R2_fvm <- decomp_fixed + decomp_varslopes + decomp_varmeans
+        R2_v <- decomp_varslopes
+        R2_m <- decomp_varmeans
+        R2_f_w <- decomp_fixed_within_w
+        R2_f_b <- decomp_fixed_between_b
+        R2_fv_w <- decomp_fixed_within_w + decomp_varslopes_w
+        R2_v_w <- decomp_varslopes_w
+        R2_m_b <- decomp_varmeans_b
+
+      }
+
+      if (isTRUE(!clustermeancentered)) {
+
+        R2_f <- decomp_fixed_notdecomp
+        R2_fv <- decomp_fixed_notdecomp + decomp_varslopes_notdecomp
+        R2_fvm <- decomp_fixed_notdecomp + decomp_varslopes_notdecomp + decomp_varmeans_notdecomp
+        R2_v <- decomp_varslopes_notdecomp
+        R2_m <- decomp_varmeans_notdecomp
+
+      }
+
+      if (isTRUE(clustermeancentered)) {
+
+        decomp_table <- matrix(c(decomp_fixed_within, decomp_fixed_between, decomp_varslopes, decomp_varmeans, decomp_sigma,
+                                 decomp_fixed_within_w, "NA", decomp_varslopes_w, "NA", decomp_sigma_w,
+                                 "NA", decomp_fixed_between_b, "NA", decomp_varmeans_b, "NA"), ncol = 3L)
+
+        decomp_table <- suppressWarnings(apply(decomp_table, 2, as.numeric))
+        rownames(decomp_table) <- c("fixed, within", "fixed, between", "slope variation", "mean variation", "sigma2")
+        colnames(decomp_table) <- c("total", "within", "between")
+        R2_table <- matrix(c(R2_f1, R2_f2, R2_v, R2_m, R2_f, R2_fv, R2_fvm,
+                             R2_f_w, "NA", R2_v_w, "NA", "NA", R2_fv_w, "NA",
+                             "NA", R2_f_b, "NA", R2_m_b, "NA", "NA", "NA"), ncol = 3L)
+        R2_table <- suppressWarnings(apply(R2_table, 2, as.numeric)) # make values numeric, not character
+        rownames(R2_table) <- c("f1", "f2", "v", "m", "f", "fv", "fvm")
+        colnames(R2_table) <- c("total", "within", "between")
+
+      }
+
+      if (isTRUE(!clustermeancentered)) {
+        decomp_table <- matrix(c(decomp_fixed_notdecomp, decomp_varslopes_notdecomp, decomp_varmeans_notdecomp, decomp_sigma_notdecomp), ncol = 1L)
+        decomp_table <- suppressWarnings(apply(decomp_table, 2L, as.numeric))
+        rownames(decomp_table) <- c("fixed", "slope variation", "mean variation", "sigma2")
+        colnames(decomp_table) <- c("total")
+        R2_table <- matrix(c(R2_f, R2_v, R2_m, R2_fv, R2_fvm), ncol = 1L)
+        R2_table <- suppressWarnings(apply(R2_table, 2L, as.numeric))
+        rownames(R2_table) <- c("f", "v", "m", "fv", "fvm")
+        colnames(R2_table) <- c("total")
+
+      }
+
+      Output <- list(noquote(decomp_table), noquote(R2_table))
+      names(Output) <- c("Decompositions", "R2s")
+      return(Output)
+
+    }
+
+    #### prepare_data() Function ####
+    prepare_data <- function(model, calling_function, cluster_variable, second_model = NULL) {
+
+      # Step 1a: Pull dataframe associated with model
+      if (isTRUE(calling_function == "lme4")) {
+
+        data <- model@frame
+
+      } else {
+
+        data <- model[["data"]]
+
+      }
+
+      # Step 2a) pull interaction terms into list
+      interaction_vars <- get_interaction_vars(model)
+
+      if (isTRUE(!is.null(second_model))) {
+
+        interaction_vars_2 <- get_interaction_vars(second_model)
+        interaction_vars <-  unique(append(interaction_vars, interaction_vars_2))
+
+      }
+
+      # Step 2b) split interaction terms into halves, multiply halves to create new columns in dataframe
+      data <- add_interaction_vars_to_data(data, interaction_vars)
+
+      return(data)
+
+    }
+
+    #### add_interaction_vars_to_data() Function ####
+    add_interaction_vars_to_data <- function(data, interaction_vars) {
+
+      for (whole in interaction_vars) {
+
+        half1 <- unlist(strsplit(whole, ":"))[1L]
+        half2 <- unlist(strsplit(whole, ":"))[2L]
+
+        newcol <- data[[half1]] * data[[half2]]
+
+        data <- within(data, assign(whole, newcol))
+
+      }
+
+      return(data)
+
+    }
+
+    #### get_covs() Function ####
+    get_covs <- function(variable_list, data) {
+
+      cov_list <- c()
+
+      i <- 1L
+      for (variable in variable_list) {
+        tmp <- match(variable, names(data))
+        cov_list[i] <- tmp
+        i <- i + 1L
+      }
+
+      return(cov_list)
+
+    }
+
+    #### get_random_slope_vars() Function ####
+    get_random_slope_vars <- function(model, has_intercept, calling_function) {
+
+      # Visible global function defnition
+      ranef <- NULL
+
+      if (isTRUE(calling_function == "lme4")) {
+
+        temp_cov_list <- ranef(model)[[1L]]
+
+      } else if (calling_function == "nlme") {
+
+        temp_cov_list <- nlme::ranef(model)
+
+      }
+
+      if (isTRUE(has_intercept == 1L)) {
+
+        running_count <- 2L
+
+      } else {
+
+        running_count <- 1L
+
+      }
+
+      random_slope_vars <- c()
+      x <- 1L
+
+      while (running_count <= length(temp_cov_list)) {
+
+        random_slope_vars[x] <- names(temp_cov_list[running_count])
+
+        x <- x + 1L
+
+        running_count <- running_count + 1L
+
+      }
+
+      return(random_slope_vars)
+
+    }
+
+    #### get_cwc() Function ####
+    get_cwc <- function(l1_vars, cluster_variable, data) {
+
+      for (variable in l1_vars) {
+
+        t <- tapply(data[, variable], data[, cluster_variable], sum, na.rm = TRUE)
+
+        temp_tracker <- 0L
+
+        # sum all of the sums
+        for (i in t) { temp_tracker <- temp_tracker + i }
+
+        if (abs(temp_tracker) < 0.0000001) {
+
+          centeredwithincluster <- TRUE
+
+        } else {
+
+          centeredwithincluster <- FALSE
+
+          break
+
+        }
+
+      }
+
+      return(centeredwithincluster)
+
+    }
+
+    #### get_interaction_vars() Function ####
+    get_interaction_vars <- function(model) {
+
+      interaction_vars <- c()
+
+      x <- 1L
+      for (term in attr(terms(model), "term.labels")) {
+
+        if (isTRUE(grepl(":", term))) {
+
+          interaction_vars[x] <- term
+
+          x <- x + 1L
+
+        }
+
+      }
+
+      return(interaction_vars)
+
+    }
+
+    #### sort_variables() Function ####
+    sort_variables <- function(data, predictors, cluster_variable) {
+
+      l1_vars <- c()
+      l2_vars <- c()
+
+      l1_counter <- 1L
+      l2_counter <- 1L
+
+      for (variable in predictors) {
+
+        t <- tapply(data[, variable], data[, cluster_variable], var, na.rm = TRUE)
+
+        counter <- 1L
+
+        while (counter <= length(t)) {
+
+          if (is.na(t[[counter]])) { t[[counter]] <- 0L }
+
+          counter <- counter + 1L
+
+        }
+
+        variance_tracker <- 0L
+
+        for (i in t) { variance_tracker <- variance_tracker + i }
+
+        if (isTRUE(variance_tracker == 0L)) {
+
+          l2_vars[l2_counter] <- variable
+          l2_counter <- l2_counter + 1L
+
+        } else {
+
+          l1_vars[l1_counter] <- variable
+          l1_counter <- l1_counter + 1L
+
+        }
+
+      }
+
+      return(list("l1_vars" = l1_vars, "l2_vars" = l2_vars))
+
+    }
+
+    #...................
+    ### R-squared measures ####
+
+    r2mlm.out <- r2mlm(model)
 
     rs <- suppressWarnings(list(decomp = matrix(apply(r2mlm.out$Decomposition, 2L, as.numeric),
                                                 ncol = ncol(r2mlm.out$Decomposition),
                                                 dimnames = list(rownames(r2mlm.out$Decompositions),
                                                                 colnames(r2mlm.out$Decompositions))),
                                 r2 = matrix(apply(r2mlm.out$R2s, 2L, as.numeric), ncol = ncol(r2mlm.out$R2s),
-                                            dimnames = list(rownames(r2mlm.out$R2s),
-                                                            colnames(r2mlm.out$R2s)))))
+                                            dimnames = list(rownames(r2mlm.out$R2s), colnames(r2mlm.out$R2s)))))
 
     #...................
     ### Plot ####
