@@ -388,7 +388,7 @@ test.levene <- function(formula, data, method = c("median", "mean"),
   object <- list(call = match.call(),
                  type = "test.levene",
                  formula = formula,
-                 data = data.frame(y, factor(group), stringsAsFactors = FALSE),
+                 data = data.frame(y, group = factor(group), stringsAsFactors = FALSE),
                  plot = p,
                  args = list(method = method, conf.level = conf.level, hypo = hypo,
                              descript = descript, plot = plot, violin.alpha = violin.alpha,
